@@ -9,8 +9,10 @@ function (res_pattern = "Permus", level = "snp", from = "workspace",
     print(paste("Permutations results location:", from))
     print(paste("Permutation level:", level))
     print(paste("Threshold:", threshold))
-    if (from != "workspace" && from != "directory") {
-        stop("Argument \"from\" must be defined: \"workspace\" OR \"directory\"")
+    if (from != "workspace"){
+if(from != "directory") {
+stop("Argument \"from\" must be defined: \"workspace\" OR \"directory\"")
+}
     }
     if (missing(level)) {
         stop("Argument \"level\" must be defined: \"snp\" OR \"gene\"")
@@ -37,10 +39,10 @@ function (res_pattern = "Permus", level = "snp", from = "workspace",
                 z <- which(permus_list == x)
                 permus_list[z]
                 assign(permus_list[z], cbind(get(permus_list[z],envir=envir), 
-                  read.table(i)))
+                  read.table(i)),envir=envir)
             }
             else {
-                assign(mode, read.table(i))
+                assign(mode, read.table(i),envir=envir)
                 permus_list <- c(permus_list, mode)
             }
         }
